==> ruby-arbre_1.2.1.orig.tar.gz: arbre-1.2.1/README.md <==
# Arbre - HTML Views in Ruby

[Arbre][docs] makes it easy to generate HTML directly in Ruby. This gem was extracted from [Active Admin](https://github.com/activeadmin/active_admin).

[![Version         ][rubygems_badge]][rubygems]
[![Travis CI       ][travis_badge]][travis]
[![Tidelift        ][tidelift_badge]][tidelift]

## Goals

The purpose of Arbre is to leave the view as ruby objects as long
as possible. This allows OO Design to be used to implement the view layer.

## Getting started

* Check out [the docs][docs].

## Need help?

Please use [StackOverflow][stackoverflow] for help requests and how-to questions.

Please open GitHub issues for bugs and enhancements only, not general help requests.
Please search previous issues (and Google and StackOverflow) before creating a new issue.

## Want to support us?

Subscribe to [Tidelift][tidelift] to support Arbre and get licensing assurances and timely security notifications.

## Security contact information

Please use the Tidelift security contact to [report a security vulnerability][Tidelift security contact].
Tidelift will coordinate the fix and disclosure.

[rubygems_badge]: http://img.shields.io/gem/v/arbre.svg
[rubygems]: https://rubygems.org/gems/arbre
[travis_badge]: http://img.shields.io/travis/activeadmin/arbre/master.svg
[travis]: https://travis-ci.org/activeadmin/arbre
[tidelift_badge]: https://tidelift.com/badges/github/activeadmin/arbre
[tidelift]: https://tidelift.com/subscription/pkg/rubygems-arbre?utm_source=rubygems-arbre&utm_medium=readme

[docs]: https://activeadmin.github.io/arbre/
[stackoverflow]: http://stackoverflow.com/questions/tagged/arbre
[Tidelift security contact]: https://tidelift.com/security

==> ruby-arbre_1.4.0.orig.tar.gz: arbre-1.4.0/README.md <==
# Arbre - HTML Views in Ruby

[Arbre][docs] makes it easy to generate HTML directly in Ruby. This gem was extracted from [Active Admin](https://github.com/activeadmin/active_admin).

[![Version         ][rubygems_badge]][rubygems]
[![Github Actions  ][actions_badge]][actions]
[![Tidelift        ][tidelift_badge]][tidelift]

## Goals

The purpose of Arbre is to leave the view as ruby objects as long
as possible. This allows OO Design to be used to implement the view layer.

## Getting started

* Check out [the docs][docs].

## Need help?

Please use [StackOverflow][stackoverflow] for help requests and how-to questions.

Please open GitHub issues for bugs and enhancements only, not general help requests.
Please search previous issues (and Google and StackOverflow) before creating a new issue.

## Want to support us?

Subscribe to [Tidelift][tidelift] to support Arbre and get licensing assurances and timely security notifications.

## Security contact information

Please use the Tidelift security contact to [report a security vulnerability][Tidelift security contact].
Tidelift will coordinate the fix and disclosure.

[rubygems_badge]: http://img.shields.io/gem/v/arbre.svg
[rubygems]: https://rubygems.org/gems/arbre
[actions_badge]: https://github.com/activeadmin/arbre/workflows/ci/badge.svg
[actions]: https://github.com/activeadmin/arbre/actions
[tidelift_badge]: https://tidelift.com/badges/github/activeadmin/arbre
[tidelift]: https://tidelift.com/subscription/pkg/rubygems-arbre?utm_source=rubygems-arbre&utm_medium=referral&utm_campaign=readme

[docs]: https://activeadmin.github.io/arbre/
[stackoverflow]: http://stackoverflow.com/questions/tagged/arbre
[Tidelift security contact]: https://tidelift.com/security
